.. Django-Site-Utils documentation master file.

Django-Site-Utils Documentation
===============================

The Django Site Utils library provides a reusable Django application with
management commands and utilities for site-wide administrative actions.

It's simply a collection of tools I've found useful across multiple projects.

.. warning::
   It is currently in the alpha stage of development and not yet recommended
   for use on production sites.

.. toctree::
   :maxdepth: 2

   intro
   commands
   signals
   settings

.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`

.. * :ref:`search`
